@@ -2,10 +2,10 @@ import logging
 from datetime import datetime
 from pathlib import Path
 from typing import Union
+import copy
 
-from dateutil.parser import ParserError
 import dateutil.parser as dparse
-
+from dateutil.parser import ParserError
 
 import gantt_project_maker.gantt as gantt
 from gantt_project_maker.colors import color_to_hex
@@ -280,7 +280,6 @@ class ProjectPlanner:
         programma_color: str = None,
         vacation_color: str = None,
         output_file_name: Path = None,
-        vacation_output_file_name: Path = None,
         planning_start: datetime = None,
         planning_end: datetime = None,
         weeks_margin_left: int = None,
@@ -293,6 +292,7 @@ class ProjectPlanner:
         details: bool = None,
         filter_employees: list = None,
         save_svg_as_pdf: bool = False,
+        export_global_program: bool = False,
     ):
         """
 
@@ -357,6 +357,14 @@ class ProjectPlanner:
             name=programma_title, color=color_to_hex(programma_color)
         )
 
+        # Make the main project only with the subprojects, not the tasks
+        if export_global_program:
+            self.programma_main = gantt.Project(
+                name=programma_title, color=color_to_hex(programma_color)
+            )
+        else:
+            self.programma_main = None
+
         # Make the project to store all the vacations
         self.vacations_gantt = gantt.Project(
             name=vacations_title, color=color_to_hex(vacation_color)
@@ -690,10 +698,24 @@ class ProjectPlanner:
             color=employee_color,
             font=gantt.get_font_attributes(font_weight="bold", font_size="20"),
         )
+        if self.programma_main is not None:
+            projects_employee_main = gantt.Project(
+                name=subprojects_title,
+                color=employee_color,
+                font=gantt.get_font_attributes(font_weight="bold", font_size="20"),
+            )
+        else:
+            projects_employee_main = None
 
         _logger.info(f"Add all projects of {subprojects_title}")
         for project_key, project_values in subprojects_info.items():
             project_name = project_values.get("title", project_key)
+            project_name_global = project_values.get("global_title", project_name)
+            projects_employee_global = project_values.get("global_employees")
+            if projects_employee_global is not None and isinstance(
+                projects_employee_global, str
+            ):
+                projects_employee_global = [projects_employee_global]
 
             _logger.info(f"Making project: {project_name}")
 
@@ -702,6 +724,14 @@ class ProjectPlanner:
             _logger.debug("Creating project {}".format(project_name))
             project = gantt.Project(name=project_name, color=project_color)
 
+            if self.programma_main is not None:
+                project_main = gantt.Project(name=project_name, color=project_color)
+            else:
+                project_main = None
+            main_start_date = None
+            main_end_date = None
+            main_contributors = None
+
             # add all the other elements as attributes
             for p_key, p_value in project_values.items():
                 if not hasattr(project, p_key):
@@ -767,9 +797,15 @@ class ProjectPlanner:
                         try:
                             contributors = task.employees
                         except AttributeError:
-                            _logger.debug(
-                                "No employees found, but can be a projects, so just add"
-                            )
+                            if isinstance(task, gantt.Task):
+                                _logger.debug(
+                                    "No employees found and this is a task. Skip it!"
+                                )
+                                continue
+                            else:
+                                _logger.debug(
+                                    "No employees found, but can be a projects, so just add"
+                                )
                         else:
                             is_contributing = check_if_employee_in_contributing(
                                 filter_employees=self.filter_employees,
@@ -784,14 +820,41 @@ class ProjectPlanner:
                     if not self.details and is_detail:
                         _logger.debug(f"skipping task {task_key} as it is a detail")
                     else:
+                        # hier min en max data bijhouden
                         project.add_task(task)
 
+                        main_contributors = get_contributors(task, main_contributors, projects_employee_global)
+
+                        # each project with task is stored as a main project with the project begin and end
+                        if main_start_date is None:
+                            main_start_date = task.start_date()
+                            main_end_date = task.end_date()
+                        else:
+                            main_end_date = task.end_date()
+
+            # every project with tasks will be a course project plan as well
+            if main_start_date is not None and main_contributors is not None:
+                main_contributors = list(set(main_contributors))
+                main_task = gantt.Task(
+                    name=project_name_global,
+                    start=main_start_date,
+                    stop=main_end_date,
+                    resources=main_contributors,
+                )
+                if project_main is not None:
+                    project_main.add_task(main_task)
+
             self.subprojects[project_key] = project
             if project_key in subprojects_selection:
+                # hier project zonder taken toevoegen
                 projects_employee.add_task(project)
+                if project_main is not None:
+                    projects_employee_main.add_task(project_main)
 
         # add now all projects of the employee to the program
         self.programma.add_task(projects_employee)
+        if self.programma_main is not None:
+            self.programma_main.add_task(projects_employee_main)
 
     def write_planning(
         self,
@@ -830,6 +893,10 @@ class ProjectPlanner:
             file_base_tasks = "_".join(
                 [self.output_file_name.with_suffix("").as_posix(), period_key, "tasks"]
             )
+            if self.programma_main is not None:
+                file_base_tasks_main = file_base_tasks + "_main"
+            else:
+                file_base_tasks_main = None
             file_base_resources = file_base_tasks.replace("_tasks", "_resources")
 
             file_base_vacations = file_base_tasks.replace("_tasks", "_vacations")
@@ -842,6 +909,13 @@ class ProjectPlanner:
             file_name = planning_output_directory / Path(file_base_tasks).with_suffix(
                 suffix
             )
+            if file_base_tasks_main:
+                file_name_main = planning_output_directory / Path(
+                    file_base_tasks_main
+                ).with_suffix(suffix)
+            else:
+                file_name_main = None
+
             file_name_res = resource_output_directory / Path(
                 file_base_resources
             ).with_suffix(suffix)
@@ -900,6 +974,20 @@ class ProjectPlanner:
                 scale=scale,
                 today=today,
             )
+
+            if self.programma_main is not None:
+                _logger.info(
+                    f"Writing main project starting at {start} and ending at {end} with a scale {scale} to {file_name_main}"
+                )
+                self.programma_main.make_svg_for_tasks(
+                    filename=file_name_main,
+                    start=start,
+                    end=end,
+                    margin_left=weeks_margin_left,
+                    margin_right=weeks_margin_right,
+                    scale=scale,
+                    today=today,
+                )
             _logger.debug("Done")
 
             if self.save_svg_as_pdf:
@@ -908,11 +996,16 @@ class ProjectPlanner:
                 except ImportError as err:
                     _logger.warning(f"{err}\nFailed writing pdf because svg42pdf is")
                 else:
-                    pdf_file_name = file_name.with_suffix(".pdf")
-                    svg42pdf.svg42pdf(
-                        svg_fn=file_name.as_posix(),
-                        pdf_fn=pdf_file_name.as_posix(),
-                        method="any",
+                    for fn in (file_name, file_name_main):
+                        if fn is None:
+                            continue
+
+                        pdf_file_name = fn.with_suffix(".pdf")
+                        _logger.info(f"Saving as {pdf_file_name}")
+                        svg42pdf.svg42pdf(
+                            svg_fn=fn.as_posix(),
+                            pdf_fn=pdf_file_name.as_posix(),
+                            method="any",
                     )
 
             if write_resources:
@@ -975,7 +1068,7 @@ def check_if_employee_in_contributing(
 
     is_contributing = False
 
-    if contributing_employees is not None:
+    if contributing_employees:
         if isinstance(contributing_employees, str):
             contributing_employees = set(list([contributing_employees]))
         else:
@@ -1014,3 +1107,31 @@ def extend_suffix(output_filename: Path, extensions: Union[list, str]):
     ).with_suffix(suffix)
 
     return output_filename
+
+def get_contributors(task, contributors, projects_employee_global):
+    """
+    get of the contributors of this Task
+
+    Parameters
+    ----------
+    task
+    contributors
+    projects_employee_global
+
+    Returns
+    -------
+
+    """
+    try:
+        if task.resources:
+            for employee in task.resources:
+                if projects_employee_global:
+                    if employee.name not in projects_employee_global:
+                        continue
+                if contributors is None:
+                    contributors = [employee]
+                else:
+                    contributors.append(employee)
+    except AttributeError:
+        pass
+    return contributors
